@@ -25,6 +25,9 @@ class DropWave(Function):
             [-5.12, 5.12],
             [-5.12, 5.12],
         ])
+        assert bounds.shape[0] == dim_bx
+        assert bounds.shape[1] == 2
+
         global_minimizers = np.array([
             [0.0, 0.0],
         ])
