@@ -33,6 +33,9 @@ class GoldsteinPrice(Function):
             [-2.0, 2.0],
             [-2.0, 2.0],
         ])
+        assert bounds.shape[0] == dim_bx
+        assert bounds.shape[1] == 2
+
         global_minimizers = np.array([
             [0.0, -1.0],
         ])
