@@ -25,6 +25,9 @@ class ThreeHumpCamel(Function):
             [-5.0, 5.0],
             [-5.0, 5.0],
         ])
+        assert bounds.shape[0] == dim_bx
+        assert bounds.shape[1] == 2
+
         global_minimizers = np.array([
             [0.0, 0.0],
         ])
